SatMAD: Satellite Mission Analysis and Design
=============================================

SatMAD is an open source Python package, aiming at providing the base functionality to solve
satellite mission analysis and design as well as orbital mechanics problems with enough precision and performance
to be used in the design and operation of real satellites. The target audience is academics and amateur satellite
community, including Cubesats (and anyone else who might be interested).

The focus is on good documentation and good test coverage to produce a reliable
flight dynamics library.

Check the source code here: https://github.com/egemenimre/satmad

In addition, there is a repository of tutorials, how-to guides
and analyses in a dedicated project called SatMAD Applications,
`available at Github <https://github.com/egemenimre/satmad_applications>`_ (for Jupyter notebooks)
and `in plain document format <https://satmad-applications.readthedocs.io/>`_.


.. toctree::
    :maxdepth: 2

    about
    getting_started
    examples
    doc_index
    references

Changelog
---------
.. toctree::
    :maxdepth: 2

    changelog

Indices and Tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
